@@ -97,6 +97,7 @@ typedef struct {
 
 typedef struct {
 	GtkWidget	*vbox;
+	GtkWidget	*select;
 	GtkWidget	*save;
 	DPHistory	edit;
 } PHistory;
@@ -274,7 +275,8 @@ static void set_paning_widgets(PPaning *p)
 
 static void set_history_widgets(PHistory *p)
 {
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(p->save), p->edit.save);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(p->select), p->edit.select);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(p->save),   p->edit.save);
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -1263,18 +1265,22 @@ static void init_paning_page(P_DirPane *page)
 	gtk_box_pack_start(GTK_BOX(p->vbox), frame, FALSE, FALSE, 0);
 }
 
-static void evt_history_save_toggled(GtkWidget *wid, gpointer user)
+/* 2004-04-25 -	Store boolean when toggle button toggles. Re-usable. */
+static void evt_history_toggled(GtkWidget *wid, gpointer user)
 {
-	P_DirPane	*page = user;
-
-	page->history.edit.save = GTK_TOGGLE_BUTTON(wid)->active;
+	*(gboolean *) user = GTK_TOGGLE_BUTTON(wid)->active;
 }
 
 static void init_history_page(P_DirPane *page)
 {
 	page->history.vbox = gtk_vbox_new(FALSE, 0);
+
+	page->history.select = gtk_check_button_new_with_label(_("Remember Selected Rows?"));
+	gtk_signal_connect(GTK_OBJECT(page->history.select), "toggled", GTK_SIGNAL_FUNC(evt_history_toggled), &page->history.edit.select);
+	gtk_box_pack_start(GTK_BOX(page->history.vbox), page->history.select, FALSE, FALSE, 0);
+	
 	page->history.save = gtk_check_button_new_with_label(_("Save History Lists?"));
-	gtk_signal_connect(GTK_OBJECT(page->history.save), "toggled", GTK_SIGNAL_FUNC(evt_history_save_toggled), page);
+	gtk_signal_connect(GTK_OBJECT(page->history.save), "toggled", GTK_SIGNAL_FUNC(evt_history_toggled), &page->history.edit.save);
 	gtk_box_pack_start(GTK_BOX(page->history.vbox), page->history.save, FALSE, FALSE, 0);
 }
 
@@ -1507,7 +1513,8 @@ static void save_paning(FILE *out, DPPaning *p)
 static void save_history(FILE *out, DPHistory *p)
 {
 	xml_put_node_open(out, "DirPaneHistory");
-	xml_put_boolean(out, "save", p->save);
+	xml_put_boolean(out, "select", p->select);
+	xml_put_boolean(out, "save",   p->save);
 	xml_put_node_close(out, "DirPaneHistory");
 }
 
@@ -1747,6 +1754,8 @@ static void load_history(const XmlNode *node, DPHistory *history)
 {
 	gboolean	tmp;
 
+	if(xml_get_boolean(node, "select", &tmp))
+		history->select = tmp;
 	if(xml_get_boolean(node, "save", &tmp))
 		history->save = tmp;
 }
