@@ -414,6 +414,24 @@ static void evt_aprop_unselected(GtkWidget *wid, gint row, gint column, GdkEvent
 	}
 }
 
+/* 2004-02-24 -	Action was renamed. */
+static void evt_aprop_name_changed(GtkWidget *wid, gpointer user)
+{
+	P_Styles	*page = user;
+
+	if((page != NULL) && (page->curr_style != NULL) && (page->curr_prop != NULL) && (page->curr_arow >= 0))
+	{
+		gchar	*oname, *nname;
+
+		gtk_clist_get_text(GTK_CLIST(page->dpaction.actions), page->curr_arow, 0, &oname);
+		if((oname != NULL) && (nname = gtk_entry_get_text(GTK_ENTRY(wid))) != NULL)
+		{
+			if(stl_style_property_rename(page->curr_style, oname, nname))	/* Will fail on collision. */
+				gtk_clist_set_text(GTK_CLIST(page->dpaction.actions), page->curr_arow, 0, nname);
+		}
+	}
+}
+
 /* 1999-05-25 -	Command sequence of current action property changed. Register that. */
 static void evt_aprop_cmdseq_changed(GtkWidget *wid, gpointer user)
 {
@@ -632,6 +650,7 @@ static void build_paction(P_Styles *page)
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
 	pa->aname = gtk_entry_new_with_max_length(STL_PROPERTY_NAME_SIZE - 1);
 	gtk_entry_set_editable(GTK_ENTRY(pa->aname), FALSE);
+	gtk_signal_connect(GTK_OBJECT(pa->aname), "changed", GTK_SIGNAL_FUNC(evt_aprop_name_changed), page);
 	gtk_table_attach(GTK_TABLE(table), pa->aname, 1, 3, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 	label = gtk_label_new(_("Command"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
