@@ -14,7 +14,7 @@
 #include "dirpane.h"
 #include "iconutil.h"
 
-#include "cfg_gui.h"
+#include "configure.h"
 #include "cfg_module.h"
 #include "cfg_styles.h"
 
@@ -34,7 +34,7 @@ typedef struct {		/* Just a little helper structure for the identification. */
 typedef struct {
 	GtkWidget	*vbox;		/* The usual mandatory root vbox. */
 	GtkWidget	*scwin;		/* Scrolled window wrapping main clist. */
-	GtkWidget	*clist;		/* Clist showing exisiting types. */
+	GtkWidget	*clist;		/* Clist showing existing types. */
 
 	GtkWidget	*ntable;	/* Table holding the type name widgetry. */
 	GtkWidget	*name;		/* Entry widget for type name. */
@@ -82,8 +82,7 @@ static void set_widgets(P_Types *page, FType *tpe)
 	gint	iflags[] = { FTFL_REQSUFFIX, FTFL_NAMEMATCH, FTFL_FILEMATCH },
 		pflags[] = { FTPM_SETUID, FTPM_SETGID, FTPM_STICKY, FTPM_READ, FTPM_WRITE, FTPM_EXECUTE },
 		igflags[] = { 0, FTFL_NAMEGLOB, FTFL_FILEGLOB },
-		incflags[] = { 0, FTFL_NAMENOCASE, FTFL_FILENOCASE };
-	guint	i;
+		incflags[] = { 0, FTFL_NAMENOCASE, FTFL_FILENOCASE }, i;
 
 	itext[0] = tpe->suffix;
 	itext[1] = tpe->name_re_src;
@@ -147,7 +146,7 @@ static void set_widgets(P_Types *page, FType *tpe)
 						gtk_pixmap_set(GTK_PIXMAP(page->sicon), ipix, imsk);
 				}
 			}
-			g_snprintf(buf, sizeof buf, _("%s  -  Click to change..."), stl_style_get_name(tpe->style));
+			g_snprintf(buf, sizeof buf, _("%s - Click to Change..."), stl_style_get_name(tpe->style));
 			gtk_label_set_text(GTK_LABEL(page->slabel), buf);
 		}
 		gtk_widget_set_sensitive(page->sframe, TRUE);
@@ -160,7 +159,7 @@ static void set_widgets(P_Types *page, FType *tpe)
 /* 1998-08-13 -	Reset the state of all the type-editing widgets. */
 static void reset_widgets(P_Types *page)
 {
-	int	i;
+	gint	i;
 
 	page->curr_type = NULL;
 	page->row	= -1;
@@ -200,7 +199,7 @@ static void reset_widgets(P_Types *page)
 /* 1998-12-13 -	Broke out the actual list updating code, since it's now needed more. */
 static void update_clist(P_Types *page)
 {
-	char	*text[] = { NULL };
+	gchar	*text[] = { NULL };
 	gint	row;
 	GList	*iter;
 
@@ -220,8 +219,8 @@ static void update_clist(P_Types *page)
 */
 static void copy_type(gpointer data, gpointer user)
 {
-	P_Types	*page = (P_Types *) user;
-	FType	*tpe = (FType *) data, *nt;
+	P_Types	*page = user;
+	FType	*tpe = data, *nt;
 
 	if(tpe == NULL)
 		return;
@@ -236,32 +235,31 @@ static void populate_clist(MainInfo *min, P_Types *page)
 	gtk_clist_clear(GTK_CLIST(page->clist));
 	reset_widgets(page);
 
-	g_list_foreach(min->cfg.type, copy_type, (gpointer) page);
+	g_list_foreach(min->cfg.type, copy_type, page);
 	update_clist(page);
 }
 
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-08-13 -	Something was selected in the main clist. Update editing widgets. */
-static gint evt_clist_select(GtkWidget *wid, gint row, gint column, GdkEventButton *evt)
+static gint evt_clist_select(GtkWidget *wid, gint row, gint column, GdkEventButton *evt, gpointer user)
 {
+	P_Types	*page = user;
 	FType	*tpe;
-	P_Types	*page = (P_Types *) gtk_object_get_user_data(GTK_OBJECT(wid));
 
-	if((tpe = (FType *) gtk_clist_get_row_data(GTK_CLIST(wid), row)) != NULL)
+	if((tpe = gtk_clist_get_row_data(GTK_CLIST(wid), row)) != NULL)
 	{
 		page->curr_type = tpe;
 		page->row	= row;
 		set_widgets(page, tpe);
 	}
-
 	return TRUE;
 }
 
 /* 1998-08-13 -	This gets called when there is no longer a selection in the clist. */
-static gint evt_clist_unselect(GtkWidget *wid, gint row, gint column, GdkEventButton *evt)
+static gint evt_clist_unselect(GtkWidget *wid, gint row, gint column, GdkEventButton *evt, gpointer user)
 {
-	P_Types	*page = (P_Types *) gtk_object_get_user_data(GTK_OBJECT(wid));
+	P_Types	*page = user;
 
 	page->curr_type = NULL;		/* Must be done _before_ reset_widgets()! Tricky! */
 	page->row = -1;
@@ -275,9 +273,9 @@ static gint evt_clist_unselect(GtkWidget *wid, gint row, gint column, GdkEventBu
 /* 1998-08-13 -	User is editing the name. Copy it as soon as it changes. Note that there is
 **		no unique-ness requirement for type names. That simplifies things.
 */
-static gint evt_name_changed(GtkWidget *wid, gpointer data)
+static gint evt_name_changed(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 	gchar	*text;
 
 	if(page->curr_type != NULL)
@@ -291,9 +289,9 @@ static gint evt_name_changed(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-08-13 -	This is the callback for (all seven) mode check buttons. */
-static gint evt_mode_clicked(GtkWidget *wid, gpointer data)
+static gint evt_mode_clicked(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
 
 	if(page->curr_type == NULL)
@@ -307,10 +305,10 @@ static gint evt_mode_clicked(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-09-07 -	User hit the "require permissions" check button. */
-static gint evt_id_reqperm_clicked(GtkWidget *wid, gpointer data)
+static gint evt_id_reqperm_clicked(GtkWidget *wid, gpointer user)
 {
+	P_Types	*page = user;
 	gint	state;
-	P_Types	*page = (P_Types *) data;
 
 	if(page->curr_type == NULL)
 		return TRUE;
@@ -328,10 +326,10 @@ static gint evt_id_reqperm_clicked(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-09-07 -	User clicked one of the permission toggle buttons. Remember. */
-static gint evt_id_perm_clicked(GtkWidget *wid, gpointer data)
+static gint evt_id_perm_clicked(GtkWidget *wid, gpointer user)
 {
+	P_Types	*page = user;
 	gint	flag;
-	P_Types	*page = (P_Types *) data;
 
 	if(page->curr_type == NULL)
 		return TRUE;
@@ -347,12 +345,12 @@ static gint evt_id_perm_clicked(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-08-13 -	User clicked on of the check buttons for identification (suffix, name RE, 'file' RE). Act. */
-static gint evt_id_check_clicked(GtkWidget *wid, gpointer data)
+static gint evt_id_check_clicked(GtkWidget *wid, gpointer user)
 {
+	P_Types	*page = user;
 	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
 	gint	iflags[] = { FTFL_REQSUFFIX, FTFL_NAMEMATCH, FTFL_FILEMATCH };
 	gint	state;
-	P_Types	*page = (P_Types *) data;
 
 	if(page->curr_type == NULL)
 		return TRUE;
@@ -374,16 +372,14 @@ static gint evt_id_check_clicked(GtkWidget *wid, gpointer data)
 		gtk_widget_set_sensitive(page->ident[index].glob, state);
 		gtk_widget_set_sensitive(page->ident[index].nocase, state);
 	}
-
 	return TRUE;
 }
 
-static gint evt_id_entry_changed(GtkWidget *wid, gpointer data)
+static gint evt_id_entry_changed(GtkWidget *wid, gpointer user)
 {
+	P_Types	*page = user;
 	gchar	*text;
 	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
-	P_Types	*page = (P_Types *) data;
-
 
 	if(page->curr_type == NULL)
 		return TRUE;
@@ -405,14 +401,13 @@ static gint evt_id_entry_changed(GtkWidget *wid, gpointer data)
 			stu_strncpy(page->curr_type->file_re_src, text, sizeof page->curr_type->file_re_src);
 			break;
 	}
-
 	return TRUE;
 }
 
 /* 1998-08-30 -	User just clicked the glob translation check button. Do the things. */
-static gint evt_id_glob_changed(GtkWidget *wid, gpointer data)
+static gint evt_id_glob_changed(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
 	gint	flag[] = { 0, FTFL_NAMEGLOB, FTFL_FILEGLOB };
 
@@ -429,9 +424,9 @@ static gint evt_id_glob_changed(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-09-15 -	User just clicked the nocase toggle button. React! */
-static gint evt_id_nocase_changed(GtkWidget *wid, gpointer data)
+static gint evt_id_nocase_changed(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
 	gint	flag[] = { 0, FTFL_NAMENOCASE, FTFL_FILENOCASE };
 
@@ -472,10 +467,10 @@ static gint evt_style_clicked(GtkWidget *wid, gpointer user)
 /* 1998-08-14 -	User just clicked the 'Add' button. Let's add a new type to play with!
 ** 1998-12-14 -	Rewritten to work better with the new priority-less type editing system.
 */
-static gint evt_add_clicked(GtkWidget *wid, gpointer data)
+static gint evt_add_clicked(GtkWidget *wid, gpointer user)
 {
-	CfgInfo	*cfg = (CfgInfo *) gtk_object_get_user_data(GTK_OBJECT(wid));
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
+	CfgInfo	*cfg  = gtk_object_get_user_data(GTK_OBJECT(wid));
 	FType	*tpe;
 	gint	row;
 
@@ -487,9 +482,9 @@ static gint evt_add_clicked(GtkWidget *wid, gpointer data)
 		update_clist(page);
 		gtk_clist_select_row(GTK_CLIST(page->clist), row, 0);
 		gtk_clist_moveto(GTK_CLIST(page->clist), row, -1, 0.5f, 0.0f);
-		page->modified = TRUE;
 		gtk_entry_select_region(GTK_ENTRY(page->name), 0, -1);
 		gtk_widget_grab_focus(page->name);
+		page->modified = TRUE;
 	}
 	return TRUE;
 }
@@ -497,9 +492,9 @@ static gint evt_add_clicked(GtkWidget *wid, gpointer data)
 /* 1998-08-14 -	Delete button was hit, so kill the currently selected type. Tragic.
 ** 1998-12-14 -	Rewritten. Didn't use the types-module, and lost selection.
 */
-static gint evt_del_clicked(GtkWidget *wid, gpointer data)
+static gint evt_del_clicked(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 	gint	row, len;
 
 	if(page->curr_type != NULL)
@@ -509,6 +504,7 @@ static gint evt_del_clicked(GtkWidget *wid, gpointer data)
 		row = (page->row > len) ? len - 1 : page->row;
 		update_clist(page);
 		gtk_clist_select_row(GTK_CLIST(page->clist), row, 0);
+		gtk_clist_moveto(GTK_CLIST(page->clist), row, -1, 0.5f, 0.0f);
 		page->modified = TRUE;
 	}
 	return TRUE;
@@ -517,9 +513,9 @@ static gint evt_del_clicked(GtkWidget *wid, gpointer data)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-12-13 -	Move selected type up one position (increases its priority). */
-static gint evt_up_clicked(GtkWidget *wid, gpointer data)
+static gint evt_up_clicked(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 
 	if(page->curr_type != NULL)
 	{
@@ -533,9 +529,9 @@ static gint evt_up_clicked(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-12-13 -	Move selected type down, decreasing its priority. */
-static gint evt_down_clicked(GtkWidget *wid, gpointer data)
+static gint evt_down_clicked(GtkWidget *wid, gpointer user)
 {
-	P_Types	*page = (P_Types *) data;
+	P_Types	*page = user;
 
 	if(page->curr_type != NULL)
 	{
@@ -562,10 +558,6 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 			ifperm[] = { FTPM_SETUID, FTPM_SETGID, FTPM_STICKY, FTPM_READ, FTPM_WRITE, FTPM_EXECUTE }, i, y;
 	static mode_t	type[] = { S_IFREG, S_IFDIR, S_IFLNK, S_IFBLK, S_IFCHR, S_IFIFO, S_IFSOCK };
 
-	if(name == NULL)
-		return NULL;
-	*name = _("File Types");
-
 	page->min = min;
 
 	page->type = NULL;
@@ -578,64 +570,51 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	page->scwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(page->scwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	page->clist = gtk_clist_new(1);
-	gtk_signal_connect(GTK_OBJECT(page->clist), "select_row", GTK_SIGNAL_FUNC(evt_clist_select), NULL);
-	gtk_signal_connect(GTK_OBJECT(page->clist), "unselect_row", GTK_SIGNAL_FUNC(evt_clist_unselect), NULL);
-	gtk_object_set_user_data(GTK_OBJECT(page->clist), (gpointer) page);
+	gtk_signal_connect(GTK_OBJECT(page->clist), "select_row", GTK_SIGNAL_FUNC(evt_clist_select), page);
+	gtk_signal_connect(GTK_OBJECT(page->clist), "unselect_row", GTK_SIGNAL_FUNC(evt_clist_unselect), page);
 	gtk_container_add(GTK_CONTAINER(page->scwin), page->clist);
-	gtk_widget_show(page->clist);
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->scwin, TRUE, TRUE, 0);
-	gtk_widget_show(page->scwin);
 
 	page->ntable = gtk_table_new(2, 2, FALSE);
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(page->ntable), label, 0, 1, 0, 1,  GTK_FILL,0,5,0);
-	gtk_widget_show(label);
 	page->name = gtk_entry_new_with_max_length(STL_STYLE_NAME_SIZE - 1);
-	page->sig_name = gtk_signal_connect(GTK_OBJECT(page->name), "changed", GTK_SIGNAL_FUNC(evt_name_changed), (gpointer) page);
+	page->sig_name = gtk_signal_connect(GTK_OBJECT(page->name), "changed", GTK_SIGNAL_FUNC(evt_name_changed), page);
 	gtk_table_attach_defaults(GTK_TABLE(page->ntable), page->name, 1, 2, 0, 1);
-	gtk_widget_show(page->name);
 
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->ntable, FALSE, FALSE, 0);
-	gtk_widget_show(page->ntable);
 
 	page->iframe = gtk_frame_new(_("Identification"));
 	page->itable = gtk_table_new(7, 3, FALSE);
 	label = gtk_label_new(_("Require Type"));
 	gtk_table_attach(GTK_TABLE(page->itable), label, 0, 1, 0, 1,  GTK_FILL,0,0,0);
-	gtk_widget_show(label);
 	page->ithbox = gtk_hbox_new(FALSE, 0);
 
 	page->itlist = gui_radio_group_new(7, tlab, page->itype);
 	page->itmode = type;
 	for(i = 0; i < 7; i++)
 	{
-		gtk_signal_connect(GTK_OBJECT(page->itype[i]), "clicked", GTK_SIGNAL_FUNC(evt_mode_clicked), (gpointer) page);
+		gtk_signal_connect(GTK_OBJECT(page->itype[i]), "clicked", GTK_SIGNAL_FUNC(evt_mode_clicked), page);
 		gtk_object_set_user_data(GTK_OBJECT(page->itype[i]), GINT_TO_POINTER(i));
 		gtk_box_pack_start(GTK_BOX(page->ithbox), page->itype[i], TRUE, TRUE, 0);
-		gtk_widget_show(page->itype[i]);
 	}
 	gtk_table_attach(GTK_TABLE(page->itable), page->ithbox, 1, 3, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
-	gtk_widget_show(page->ithbox);
 
 	page->irperm = gtk_check_button_new_with_label(_("Require Protection"));
-	gtk_signal_connect(GTK_OBJECT(page->irperm), "clicked", GTK_SIGNAL_FUNC(evt_id_reqperm_clicked), (gpointer) page);
+	gtk_signal_connect(GTK_OBJECT(page->irperm), "clicked", GTK_SIGNAL_FUNC(evt_id_reqperm_clicked), page);
 	gtk_table_attach(GTK_TABLE(page->itable), page->irperm, 0, 1, 1, 2,  GTK_FILL,0,0,0);
-	gtk_widget_show(page->irperm);
 	page->iphbox = gtk_hbox_new(FALSE, 0);
 	for(i = 0; i < 6; i++)
 	{
 		page->iperm[i] = gtk_toggle_button_new_with_label(_(iplab[i]));
 		gtk_object_set_user_data(GTK_OBJECT(page->iperm[i]), GINT_TO_POINTER(ifperm[i]));
-		gtk_signal_connect(GTK_OBJECT(page->iperm[i]), "clicked", GTK_SIGNAL_FUNC(evt_id_perm_clicked), (gpointer) page);
+		gtk_signal_connect(GTK_OBJECT(page->iperm[i]), "clicked", GTK_SIGNAL_FUNC(evt_id_perm_clicked), page);
 		gtk_box_pack_start(GTK_BOX(page->iphbox), page->iperm[i], TRUE, TRUE, 0);
-		gtk_widget_show(page->iperm[i]);
 	}
 	gtk_table_attach(GTK_TABLE(page->itable), page->iphbox, 1, 3, 1, 2,  GTK_EXPAND | GTK_FILL,0,0,0);
-	gtk_widget_show(page->iphbox);
 
 	sep = gtk_hseparator_new();
 	gtk_table_attach(GTK_TABLE(page->itable), sep, 0, 3, 4, 5, GTK_EXPAND | GTK_FILL,0,0,5);
-	gtk_widget_show(sep);
 
 	for(i = 0; i < 3; i++)
 	{
@@ -643,15 +622,13 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 
 		page->ident[i].check = gtk_check_button_new_with_label(_(idlab[i]));
 		gtk_object_set_user_data(GTK_OBJECT(page->ident[i].check), GINT_TO_POINTER(i));
-		gtk_signal_connect(GTK_OBJECT(page->ident[i].check), "clicked", GTK_SIGNAL_FUNC(evt_id_check_clicked), (gpointer) page);
+		gtk_signal_connect(GTK_OBJECT(page->ident[i].check), "clicked", GTK_SIGNAL_FUNC(evt_id_check_clicked), page);
 		gtk_table_attach(GTK_TABLE(page->itable), page->ident[i].check, 0, 1, y, y+1,  GTK_FILL,0,0,0);
-		gtk_widget_show(page->ident[i].check);
 
 		page->ident[i].entry = gtk_entry_new_with_max_length(idmax[i] - 1);
 		gtk_object_set_user_data(GTK_OBJECT(page->ident[i].entry), GINT_TO_POINTER(i));
-		gtk_signal_connect(GTK_OBJECT(page->ident[i].entry), "changed", GTK_SIGNAL_FUNC(evt_id_entry_changed), (gpointer) page);
+		gtk_signal_connect(GTK_OBJECT(page->ident[i].entry), "changed", GTK_SIGNAL_FUNC(evt_id_entry_changed), page);
 		gtk_table_attach(GTK_TABLE(page->itable), page->ident[i].entry, 1, (i == 0) ? 3 : 2, y, y+1,  GTK_EXPAND | GTK_FILL,0,0,0);
-		gtk_widget_show(page->ident[i].entry);
 
 		if(i >= 1)
 		{
@@ -660,80 +637,66 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 			hbox = gtk_hbox_new(FALSE, 0);
 			page->ident[i].glob = gtk_check_button_new_with_label(_("Glob?"));
 			gtk_object_set_user_data(GTK_OBJECT(page->ident[i].glob), GINT_TO_POINTER(i));
-			gtk_signal_connect(GTK_OBJECT(page->ident[i].glob), "clicked", GTK_SIGNAL_FUNC(evt_id_glob_changed), (gpointer) page);
+			gtk_signal_connect(GTK_OBJECT(page->ident[i].glob), "clicked", GTK_SIGNAL_FUNC(evt_id_glob_changed), page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->ident[i].glob, FALSE, FALSE, 0);
-			gtk_widget_show(page->ident[i].glob);
 
-			page->ident[i].nocase = gtk_check_button_new_with_label(_("No Case?"));
+			page->ident[i].nocase = gtk_check_button_new_with_label(_("Ignore Case?"));
 			gtk_object_set_user_data(GTK_OBJECT(page->ident[i].nocase), GINT_TO_POINTER(i));
-			gtk_signal_connect(GTK_OBJECT(page->ident[i].nocase), "clicked", GTK_SIGNAL_FUNC(evt_id_nocase_changed), (gpointer) page);
+			gtk_signal_connect(GTK_OBJECT(page->ident[i].nocase), "clicked", GTK_SIGNAL_FUNC(evt_id_nocase_changed), page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->ident[i].nocase, FALSE, FALSE, 0);
-			gtk_widget_show(page->ident[i].nocase);
 
-			gtk_table_attach(GTK_TABLE(page->itable), hbox, 2, 3, y, y + 1, 0,0,0,0);
-			gtk_widget_show(hbox);
+			gtk_table_attach(GTK_TABLE(page->itable), hbox, 2, 3, y, y + 1, GTK_SHRINK,0,0,0);
 		}
 	}
 	gtk_container_add(GTK_CONTAINER(page->iframe), page->itable);
-	gtk_widget_show(page->itable);
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->iframe, FALSE, FALSE, 5);
-	gtk_widget_show(page->iframe);
 
 	page->sframe = gtk_frame_new(_("Type's Style"));
 	page->shbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Style"));
 	gtk_box_pack_start(GTK_BOX(page->shbox), label, FALSE, FALSE, 5);
-	gtk_widget_show(label);
 	page->sbtn = gtk_button_new();
-	gtk_signal_connect(GTK_OBJECT(page->sbtn), "clicked", GTK_SIGNAL_FUNC(evt_style_clicked), (gpointer) page);
+	gtk_signal_connect(GTK_OBJECT(page->sbtn), "clicked", GTK_SIGNAL_FUNC(evt_style_clicked), page);
 
 	page->sbhbox = gtk_hbox_new(FALSE, 0);
 	page->sicon  = NULL;
 	page->slabel = gtk_label_new("");
 	gtk_box_pack_start(GTK_BOX(page->sbhbox), page->slabel, TRUE, TRUE, 0);
-	gtk_widget_show(page->slabel);
 	gtk_container_add(GTK_CONTAINER(page->sbtn), page->sbhbox);
-	gtk_widget_show(page->sbhbox);
 
 	gtk_box_pack_start(GTK_BOX(page->shbox), page->sbtn, TRUE, TRUE, 5);
-	gtk_widget_show(page->sbtn);
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), page->shbox, FALSE, FALSE, 5);
-	gtk_widget_show(page->shbox);
 	gtk_container_add(GTK_CONTAINER(page->sframe), vbox);
-	gtk_widget_show(vbox);
 
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->sframe, FALSE, FALSE, 5);
-	gtk_widget_show(page->sframe);
 
 	page->bhbox = gtk_hbox_new(FALSE, 0);
 	page->add = gtk_button_new_with_label(_("Add"));
-	gtk_object_set_user_data(GTK_OBJECT(page->add), (gpointer) &min->cfg);
-	gtk_signal_connect(GTK_OBJECT(page->add), "clicked", GTK_SIGNAL_FUNC(evt_add_clicked), (gpointer) page);
+	gtk_object_set_user_data(GTK_OBJECT(page->add), &min->cfg);
+	gtk_signal_connect(GTK_OBJECT(page->add), "clicked", GTK_SIGNAL_FUNC(evt_add_clicked), page);
 	gtk_box_pack_start(GTK_BOX(page->bhbox), page->add, TRUE, TRUE, 5);
-	gtk_widget_show(page->add);
 
 	page->up = gui_arrow_button_new(GTK_ARROW_UP);
-	gtk_signal_connect(GTK_OBJECT(page->up), "clicked", GTK_SIGNAL_FUNC(evt_up_clicked), (gpointer) page);
+	gtk_signal_connect(GTK_OBJECT(page->up), "clicked", GTK_SIGNAL_FUNC(evt_up_clicked), page);
 	gtk_box_pack_start(GTK_BOX(page->bhbox), page->up, FALSE, FALSE, 0);
-	gtk_widget_show(page->up);
 
 	page->down = gui_arrow_button_new(GTK_ARROW_DOWN);
-	gtk_signal_connect(GTK_OBJECT(page->down), "clicked", GTK_SIGNAL_FUNC(evt_down_clicked), (gpointer) page);
+	gtk_signal_connect(GTK_OBJECT(page->down), "clicked", GTK_SIGNAL_FUNC(evt_down_clicked), page);
 	gtk_box_pack_start(GTK_BOX(page->bhbox), page->down, FALSE, FALSE, 0);
-	gtk_widget_show(page->down);
 
 	page->del = gtk_button_new_with_label(_("Delete"));
-	gtk_signal_connect(GTK_OBJECT(page->del), "clicked", GTK_SIGNAL_FUNC(evt_del_clicked), (gpointer) page);
+	gtk_signal_connect(GTK_OBJECT(page->del), "clicked", GTK_SIGNAL_FUNC(evt_del_clicked), page);
 	gtk_box_pack_start(GTK_BOX(page->bhbox), page->del, TRUE, TRUE, 5);
-	gtk_widget_show(page->del);
 
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->bhbox, FALSE, FALSE, 5);
-	gtk_widget_show(page->bhbox);
 
-	gtk_widget_show(page->vbox);		
+	gtk_widget_show_all(page->vbox);		
 
-	return page->vbox;
+	cfg_tree_level_append(_("Types"), page->vbox);
+	cfg_tree_level_end();
+
+	return NULL;
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -771,8 +734,8 @@ static void ctp_accept(MainInfo *min)
 /* 1998-08-14 -	Save out a single file type. */
 static void save_type(gpointer data, gpointer user)
 {
-	FType	*tpe = (FType *) data;
-	FILE	*out = (FILE *) user;
+	FType	*tpe = data;
+	FILE	*out = user;
 
 	if(tpe == NULL)
 		return;
@@ -808,7 +771,7 @@ static void save_type(gpointer data, gpointer user)
 static gint ctp_save(MainInfo *min, FILE *out)
 {
 	xml_put_node_open(out, NODE);
-	g_list_foreach(min->cfg.type, save_type, (gpointer) out);
+	g_list_foreach(min->cfg.type, save_type, out);
 	xml_put_node_close(out, NODE);
 
 	return 1;
@@ -822,7 +785,7 @@ static gint ctp_save(MainInfo *min, FILE *out)
 */
 static void load_type(const XmlNode *node, gpointer user)
 {
-	CfgInfo		*cfg = (CfgInfo *) user;
+	CfgInfo		*cfg = user;
 	const gchar	*name = NULL, *suffix = NULL, *name_re = NULL, *file_re = NULL, *style = NULL;
 	gint		perm = 0, tmp, mode;
 	FType		*tpe;
@@ -835,7 +798,7 @@ static void load_type(const XmlNode *node, gpointer user)
 	xml_get_text(node, "file_re", &file_re);
 	xml_get_text(node, "style", &style);
 
-	if((tpe = typ_type_new(cfg, name, (mode_t) mode, (int) perm, suffix, name_re, file_re)) != NULL)
+	if((tpe = typ_type_new(cfg, name, mode, perm, suffix, name_re, file_re)) != NULL)
 	{
 		if(xml_get_boolean(node, "name_glob", &tmp) && tmp)
 			tpe->flags |= FTFL_NAMEGLOB;
@@ -861,10 +824,10 @@ static void ctp_load(MainInfo *min, const XmlNode *node)
 		next = g_list_next(old);
 		if(old->data == NULL)
 			continue;
-		typ_type_destroy((FType *) old->data);
+		typ_type_destroy(old->data);
 		min->cfg.type = g_list_remove(min->cfg.type, old->data);
 	}
-	xml_node_visit_children(node, load_type, (gpointer) &min->cfg);
+	xml_node_visit_children(node, load_type, &min->cfg);
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -882,7 +845,7 @@ static void ctp_hide(MainInfo *min)
 		next = g_list_next(old);
 		if(old->data == NULL)
 			continue;
-		typ_type_destroy((FType *) old->data);
+		typ_type_destroy(old->data);
 		page->type = g_list_remove(page->type, old->data);
 	}
 	g_list_free(page->type);
@@ -891,9 +854,9 @@ static void ctp_hide(MainInfo *min)
 
 /* ----------------------------------------------------------------------------------------- */
 
-CfgPage * ctp_describe(MainInfo *min)
+const CfgModule * ctp_describe(MainInfo *min)
 {
-	static CfgPage	desc = { NODE, ctp_init, ctp_update, ctp_accept, ctp_save, ctp_load, ctp_hide };
+	static const CfgModule	desc = { NODE, ctp_init, ctp_update, ctp_accept, ctp_save, ctp_load, ctp_hide };
 
 	return &desc;
 }
