@@ -273,24 +273,6 @@ gboolean copy_file(MainInfo *min, const gchar *from, const gchar *full_to, const
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 2003-10-10 -	Check if the directory <to> is a child directory of <from>. If it
-**		is, copying <from> into <to> is a genuine Bad Idea.
-*/
-static gboolean is_parent_of(const char *from, const char *to)
-{
-	gchar	buf1[PATH_MAX], buf2[PATH_MAX];
-
-	if(fut_path_canonicalize(from, buf1, sizeof buf1) &&
-	   fut_path_canonicalize(to,   buf2, sizeof buf2))
-	{
-		gsize	len = strlen(buf1);
-		
-		if(strncmp(buf1, buf2, len) == 0)
-			return buf2[len] == G_DIR_SEPARATOR;	/* If last char is /, buf1 is really a prefix. */
-	}
-	return FALSE;
-}
-
 /* 1998-05-21 -	Copy a directory recursively, by first creating the appropriate
 **		destination directory, and then copying all the source's contents
 **		there. When directories are found in the source, this function is
@@ -313,7 +295,7 @@ gboolean copy_dir(MainInfo *min, const gchar *from, const gchar *dest_name)
 	struct stat	sstat;
 	OvwRes		owres;
 
-	if(is_parent_of(from, dest_name))
+	if(fut_is_parent_of(from, dest_name))
 	{
 		gchar	ebuf[2 * PATH_MAX + 128];
 
@@ -330,6 +312,10 @@ gboolean copy_dir(MainInfo *min, const gchar *from, const gchar *dest_name)
 	owres = ovw_overwrite_file(min, dest_name, from);
 	switch(owres)
 	{
+	case OVW_SKIP:
+		return TRUE;
+	case OVW_CANCEL:
+		return FALSE;
 	case OVW_PROCEED_FILE:
 		if(!del_delete_file(min, dest_name))
 		{
@@ -340,9 +326,6 @@ gboolean copy_dir(MainInfo *min, const gchar *from, const gchar *dest_name)
 	case OVW_PROCEED:
 	case OVW_PROCEED_DIR:
 		break;
-	case OVW_SKIP:
-	case OVW_CANCEL:
-		return FALSE;
 	}
 
 	err_clear(min);
@@ -432,7 +415,7 @@ gint cmd_copy(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	fut_cd(old_path, NULL, 0);
 
 	if(errno && iter != NULL)
-		err_set(min, errno, "copy", dp_full_name(src, DP_SEL_INDEX(src, iter)));
+		err_set(min, errno, CMD_ID, dp_full_name(src, DP_SEL_INDEX(src, iter)));
 	dp_free_selection(slist);
 	err_show(min);
 
