@@ -45,14 +45,46 @@ typedef struct {
 static OptInfo	info_options;
 static CmdCfg	*info_cmc = NULL;
 
+/* Special little struct used to hold information during background directory sizing. */
+typedef struct {
+	GtkWidget	*size, *contents;			/* Label widgets, updated. */
+	gpointer	handle;						/* Handle from fut_dir_size_start(). */
+} DirSizeInfo;
+
 /* ----------------------------------------------------------------------------------------- */
 
+static void dir_size_update(const FUCount *count, gpointer user)
+{
+	DirSizeInfo	*dsi = user;
+	gchar	buf[64], sbuf[64], stbuf[64], btbuf[64], *st, *bt;
+
+	if(!count)
+		return;
+
+	/* Replace contents of previously built size-label. */
+	sze_put_size64(sbuf, sizeof sbuf, count->num_bytes, SZE_AUTO);
+			
+	stbuf[sizeof stbuf - 1] = '\0';
+	st = stu_tickify(stbuf + sizeof stbuf - 1, count->num_bytes,  info_options.tick[0]);
+	btbuf[sizeof btbuf - 1] = '\0';
+	bt = stu_tickify(btbuf + sizeof btbuf - 1, count->num_blocks, info_options.tick[0]);
+	g_snprintf(buf, sizeof buf, _("%s (%s bytes,\n%s blocks)"), sbuf, st, bt);
+	gtk_label_set_text(GTK_LABEL(dsi->size), buf);
+
+	/* And tell a little something about the contents. */
+	g_snprintf(buf, sizeof buf, _("%u dirs, %u files, %u symlinks"),
+			count->num_dirs, count->num_files, count->num_links);
+	gtk_label_set_text(GTK_LABEL(dsi->contents), buf);
+}
+
 static GtkWidget * label_pack(GtkWidget *table, const gchar *text, gint x, gint y, gboolean left)
 {
 	GtkWidget	*algn, *lab;
 
 	algn = gtk_alignment_new(left ? 0.0f : 0.9f, 0.0f, 0.0f, 0.0f);
 	lab  = gtk_label_new(text);
+	if(left)
+		gtk_label_set_justify(GTK_LABEL(lab), GTK_JUSTIFY_LEFT);
 	gtk_container_add(GTK_CONTAINER(algn), lab);
 	gtk_table_attach(GTK_TABLE(table), algn, x, x + 1, y, y + 1, GTK_FILL,0,4,0);
 	return lab;
@@ -71,7 +103,7 @@ static void build_date(const gchar *label, gint y, const time_t *date, const gch
 	}
 }
 
-static GtkWidget * build_info(MainInfo *min, const DirPane *dp, const DirRow *row)
+static GtkWidget * build_info(MainInfo *min, const DirPane *dp, const DirRow *row, DirSizeInfo **dsi)
 {
 	gchar		buf[128], sbuf[32], *ptr;
 	guint		y;
@@ -122,38 +154,24 @@ static GtkWidget * build_info(MainInfo *min, const DirPane *dp, const DirRow *ro
 		stu_strncpy(buf, sbuf, sizeof buf);
 	else
 	{
-		gchar	stbuf[64], *st;
+		gchar	stbuf[64], *st, btbuf[64], *bt;
 
 		stbuf[sizeof stbuf - 1] = '\0';
 		st = stu_tickify(stbuf + sizeof stbuf - 1, DP_ROW_LSTAT(row).st_size, info_options.tick[0]);
-		g_snprintf(buf, sizeof buf, _("%s (%s bytes)"), sbuf, st);
+		btbuf[sizeof btbuf - 1] = '\0';
+		bt = stu_tickify(btbuf + sizeof btbuf - 1, DP_ROW_LSTAT(row).st_blocks, info_options.tick[0]);
+		g_snprintf(buf, sizeof buf, _("%s (%s bytes,\n%s blocks)"), sbuf, st, bt);
 	}
 	szlab = label_pack(tab, buf, 1, y++, TRUE);
 	/* Building info for a directory, and recursing enabled? */
 	if(S_ISDIR(DP_ROW_LSTAT(row).st_mode) && info_options.recurse_dirs)
 	{
-		guint64	bytes = 0U;
-		FUCount	fc;
-
-		/* Collect information recursively. */
-		if(fut_dir_size_progress(min, dp_full_name(dp, DP_ROW_INDEX(dp, row)), &bytes, &fc))
-		{
-			gchar	buf[64], sbuf[64], stbuf[64], *st;
-
-			/* Replace contents of previously built size-label. */
-			sze_put_size64(sbuf, sizeof buf, bytes, SZE_AUTO);
-			
-			stbuf[sizeof stbuf - 1] = '\0';
-			st = stu_tickify(stbuf + sizeof stbuf - 1, bytes, info_options.tick[0]);
-			g_snprintf(buf, sizeof buf, _("%s (%s bytes)"), sbuf, st);
-			gtk_label_set_text(GTK_LABEL(szlab), buf);
-
-			/* And tell a little something about the contents. */
-			label_pack(tab, _("Contains"), 0, y, FALSE);
-			g_snprintf(buf, sizeof buf, _("%u dirs, %u files, %u symlinks"),
-					fc.num_dirs, fc.num_files, fc.num_links);
-			label_pack(tab, buf, 1, y++, TRUE);
-		}
+		/* Start asynchronous directory sizing. Nice. */
+		*dsi = g_malloc(sizeof *dsi);
+		(*dsi)->size     = szlab;
+		label_pack(tab, _("Contains"), 0, y, FALSE);
+		(*dsi)->contents = label_pack(tab, "(content info)", 1, y++, TRUE);
+		(*dsi)->handle   = fut_dir_size_start(dp_full_name(dp, DP_ROW_INDEX(dp, row)), dir_size_update, *dsi);
 	}
 
 	/* Is the "Show 'file' Output?" option enabled? Requires "file -n -f -" to work. */
@@ -206,15 +224,26 @@ static GtkWidget * build_info(MainInfo *min, const DirPane *dp, const DirRow *ro
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* 2003-10-16 -	Callback when Information window is closing. Stop asynch. dir sizing, if in use. */
+static void info_close(gint button, gpointer user)
+{
+	DirSizeInfo	*dsi = user;
+
+	if(dsi)
+		fut_dir_size_stop(dsi->handle);
+	g_free(dsi);
+}
+
 /* 1999-03-06 -	Create window showing all about <row>, which sits in <dp>. */
 static gint information(MainInfo *min, const DirPane *dp, const DirRow *row)
 {
+	DirSizeInfo	*dsi = NULL;
 	GtkWidget	*fr;
 
-	if((fr = build_info(min, dp, row)) != NULL)
+	if((fr = build_info(min, dp, row, &dsi)) != NULL)
 	{
 		gtk_widget_show_all(fr);
-		dlg_dialog_async_new(fr, DP_ROW_NAME(row), _("_OK"), NULL, NULL);
+		dlg_dialog_async_new(fr, DP_ROW_NAME(row), _("_OK"), info_close, dsi);
 	}
 	return fr != NULL;
 }
