@@ -6,8 +6,10 @@
 
 #include "gentoo.h"
 
+#include <ctype.h>
 #include <fcntl.h>
 
+#include "cmd_delete.h"
 #include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
@@ -27,6 +29,8 @@ static gboolean do_join(MainInfo *min, DirPane *src, DirPane *dst, GtkCList *cli
 {
 	gchar		buf[PATH_MAX], *str;
 	gsize		done_size = 0U;
+	OvwRes		owres;
+	gboolean	doit = TRUE;
 
 	/* Protect against empty destination name. */
 	if((str = gtk_entry_get_text(entry)) == NULL || *str == '\0')
@@ -37,7 +41,23 @@ static gboolean do_join(MainInfo *min, DirPane *src, DirPane *dst, GtkCList *cli
 
 	ovw_overwrite_begin(min, _("\"%s\" Already Exists - Continue With Join?"), 0U);
 	g_snprintf(buf, sizeof buf, "%s/%s", dst->dir.path, str);
-	if(ovw_overwrite_file(min, buf, NULL) == OVW_PROCEED)
+	owres = ovw_overwrite_file(min, buf, NULL);
+	switch(owres)
+	{
+	case OVW_SKIP:
+	case OVW_CANCEL:
+		doit = FALSE;
+		break;
+	case OVW_PROCEED:
+		break;
+	case OVW_PROCEED_FILE:
+		doit = del_delete_file(min, buf);
+		break;
+	case OVW_PROCEED_DIR:
+		doit = del_delete_dir(min, buf, FALSE);
+		break;
+	}
+	if(doit)
 	{
 		gint	fout;
 
@@ -55,7 +75,11 @@ static gboolean do_join(MainInfo *min, DirPane *src, DirPane *dst, GtkCList *cli
 					pgs_progress_item_begin(min, DP_ROW_NAME(dr), DP_ROW_STAT(dr).st_size);
 					put = fut_copy(fin, fout, 256 << 10);
 					pgs_progress_item_end(min);
-					close(fin);
+					if(close(fin) != 0)
+					{
+						err_set(min, errno, CMD_ID, DP_ROW_NAME(dr));
+						break;
+					}
 					if(put != DP_ROW_STAT(dr).st_size)
 					{
 						err_set(min, 000, CMD_ID, DP_ROW_NAME(dr));
@@ -82,7 +106,7 @@ static gboolean do_join(MainInfo *min, DirPane *src, DirPane *dst, GtkCList *cli
 	}
 	ovw_overwrite_end(min);
 
-	return done_size == total_size;
+	return doit ? done_size == total_size : TRUE;
 }
 
 gint cmd_join(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
@@ -114,9 +138,9 @@ gint cmd_join(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		{
 			Dialog		*dlg;
 			GtkWidget	*scwin, *vbox, *label, *clist, *entry;
-			gchar		buf[64];
-			const gchar	*text[1];
-			gint		row;
+			gchar		buf[FILENAME_MAX + 64];
+			const gchar	*text[1], *first = NULL;
+			gint		row, len;
 
 			vbox  = gtk_vbox_new(FALSE, 0);
 			label = gtk_label_new(_("Click and Drag Files to Reorder, Then Click Join."));
@@ -147,6 +171,8 @@ gint cmd_join(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 					text[0] = DP_ROW_NAME((DirRow *) iter->data);
 					row = gtk_clist_append(GTK_CLIST(clist), (gchar **) text);
 					gtk_clist_set_row_data(GTK_CLIST(clist), row, iter->data);
+					if(!first)			/* Remember first name, for entry. */
+						first = text[0];
 				}
 			}
 			gtk_container_add(GTK_CONTAINER(scwin), clist);
@@ -155,6 +181,18 @@ gint cmd_join(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 			label = gtk_label_new(_("Enter Destination File Name"));
 			gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 5);
 			entry = gtk_entry_new_with_max_length(FILENAME_MAX - 1);
+			/* Heuristic: remove trailing hexadecimal number and period, and position cursor before last remaining period. */
+			if((len = g_snprintf(buf, sizeof buf, "%s", first)) > 0)
+			{
+				const gchar	*dot;
+				int	i;
+
+				for(i = len - 1; i > 0 && (isxdigit(buf[i]) || buf[i] == '.'); i--)
+					buf[i] = '\0';
+				gtk_entry_set_text(GTK_ENTRY(entry), buf);
+				if((dot = strrchr(buf, '.')) != NULL)
+					gtk_entry_set_position(GTK_ENTRY(entry), dot - buf);
+			}
 			gtk_box_pack_start(GTK_BOX(vbox), entry, FALSE, FALSE, 0);
 
 			dlg = dlg_dialog_sync_new(vbox, _("Join"), _("_Join|_Cancel"));
