@@ -11,6 +11,7 @@
 */
 
 #include "gentoo.h"
+#include "cmd_delete.h"
 #include "errors.h"
 #include "dirpane.h"
 #include "overwrite.h"
@@ -56,7 +57,6 @@ static gint ren_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 {
 	RenInfo		*ren = user;
 	const gchar	*old_name, *new_name;
-	OvwRes		ores;
 
 	old_name = DP_ROW_NAME(row);
 	new_name = gtk_entry_get_text(GTK_ENTRY(ren->entry));
@@ -72,11 +72,24 @@ static gint ren_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 		dp_unselect(src, DP_ROW_INDEX(src, row));
 		return 1;
 	}
-	ores = ovw_overwrite_file(ren->min, new_name, NULL);
-	if(ores == OVW_SKIP)
+	/* Check for overwrite, and attempt to clear the way. */
+	switch(ovw_overwrite_file(ren->min, new_name, NULL))
+	{
+	case OVW_SKIP:
 		return 1;
-	else if(ores == OVW_CANCEL)
-		return 0;		/* This tells the generic handler to quit. Nice and simple. */
+	case OVW_CANCEL:
+		return 0;
+	case OVW_PROCEED:
+		break;
+	case OVW_PROCEED_FILE:
+		if(!del_delete_file(min, new_name))
+			return 0;
+		break;
+	case OVW_PROCEED_DIR:
+		if(!del_delete_dir(min, new_name, FALSE))
+			return 0;
+		break;
+	}
 
 	err_clear(min);
 	if(rename(old_name, new_name) != 0)
