@@ -28,6 +28,8 @@
 
 #include "cmd_renamere.h"
 
+#define	CMD_ID	"renamere"
+
 /* ----------------------------------------------------------------------------------------- */
 
 typedef struct {
@@ -119,7 +121,7 @@ static gint rename_simple(RenREInfo *ri)
 			{
 				err = errno;
 				dp_rescan_post_cmd(ri->src);
-				err_set(ri->min, err, "RenameRE", DP_SEL_NAME(iter));
+				err_set(ri->min, err, CMD_ID, DP_SEL_NAME(iter));
 			}
 			else
 				dp_unselect(ri->src, DP_SEL_INDEX(ri->src, iter));
@@ -221,7 +223,7 @@ static gint rename_regexp(RenREInfo *ri)
 						{
 							err = errno;
 							dp_rescan_post_cmd(ri->src);
-							err_set(ri->min, err, "RenameRE", DP_SEL_NAME(iter));
+							err_set(ri->min, err, CMD_ID, DP_SEL_NAME(iter));
 						}
 						else
 							dp_unselect(ri->src, DP_SEL_INDEX(ri->src, iter));
@@ -316,7 +318,7 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.re_vbox, gtk_label_new(_("Reg Exp")));
 		gtk_widget_show_all(ri.re_vbox);
 
-		ri.dlg = dlg_dialog_sync_new(ri.nbook, "RenameRE", NULL);
+		ri.dlg = dlg_dialog_sync_new(ri.nbook, _("RenameRE"), NULL);
 
 		ri.page = 0;
 	}
