@@ -14,6 +14,7 @@
 
 #include <ctype.h>
 
+#include "cmd_delete.h"
 #include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
@@ -168,18 +169,27 @@ static gint do_renameseq(RenSeqInfo *rsi, DirPane *src)
 					continue;
 				}
 				else if(res == OVW_CANCEL)
-				{
-					for(; i < num; i++)
-					{
-						if(!(restore_from_temp(tmppfx, slist, i)))
-							break;
-					}
 					break;
+				else if(res == OVW_PROCEED_FILE)
+				{
+					if(!del_delete_file(rsi->min, name))
+						break;
+				}
+				else if(res == OVW_PROCEED_DIR)
+				{
+					if(!del_delete_dir(rsi->min, name, FALSE))
+						break;
 				}
 				if(rename(tmpname, name) != 0)
 					break;
 			}
 			ovw_overwrite_end(rsi->min);
+			/* If we broke out early from the loop, restore. */
+			for(; i < num; i++)
+			{
+				if(!(restore_from_temp(tmppfx, slist, i)))
+					break;
+			}
 		}
 	}
 	dp_free_selection(slist);
