@@ -25,14 +25,17 @@
 
 #include <stdlib.h>
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <regex.h>
 
 #include <gdk/gdkkeysyms.h>
 
+#include "cmdparse.h"
 #include "dirpane.h"
 #include "dialog.h"
 #include "dpformat.h"
 #include "events.h"
+#include "fileutil.h"
 #include "strutil.h"
 #include "types.h"
 
@@ -55,21 +58,40 @@
 #define	SM_ACTION_UNSELECT	(1)
 #define	SM_ACTION_TOGGLE	(2)
 
-/* Selection parameters. Filled-in either by GUI, or by direct command arguments. */
+typedef void (*SelAction)(DirPane *, gint);
+
+/* Base selection parameters. Filled-in either by GUI, or by direct command arguments. */
 typedef struct {
-	GString		*re;		/* The actual regular expression string. */
 	guint		set;		/* In which set of rows should we operate? */
 	guint		type;		/* Do we operate only on files, dirs, or both? */
 	guint		action;		/* What do we do with matching rows? */
 	DPContent	content;	/* Which field of the pane should we match against? */
+} SelParam;
+
+typedef struct {
+	SelParam	basic;		/* Basic parameters (selection set, action, content). */
 	gboolean	glob;		/* Treat the RE as a glob pattern? */
 	gboolean	invert;		/* Invert the matching sense? */
 	gboolean	full;		/* Require RE to match entire row? */
 	gboolean	nocase;		/* Ignore case differences? */
-} SelParam;
+	GString		*re;		/* The actual regular expression string. */
+} SelParamRE;
 
-static SelParam	old_sp = { NULL, SM_SET_ALL, SM_TYPE_ALL, SM_ACTION_SELECT, DPC_NAME,
-			   TRUE, FALSE, TRUE, FALSE };
+typedef struct {
+	SelParam	basic;		/* Basic parameters (selection set, action, content). */
+	GString		*cmd;		/* Shell command to execute. */
+} SelParamShell;
+
+static SelParamRE old_sp_re = {
+	{ SM_SET_ALL, SM_TYPE_ALL, SM_ACTION_SELECT, DPC_NAME },
+	TRUE, FALSE, TRUE, FALSE, NULL 
+};
+
+static SelParamShell old_sp_shell = {
+	{ SM_SET_ALL, SM_TYPE_ALL, SM_ACTION_SELECT, DPC_NAME },
+	NULL
+};
+				
 
 /* ----------------------------------------------------------------------------------------- */
 
@@ -232,10 +254,25 @@ static guint compute_column(DirPane *dp, DPContent content)
 	return 0;
 }
 
+/* 2005-06-04 -	Select action fuction. The <action> should be one of the SM_ACTION_ values. */
+static SelAction select_action_func(gint action)
+{
+	switch(action)
+	{
+		case SM_ACTION_SELECT:
+			return dp_select;
+		case SM_ACTION_UNSELECT:
+			return dp_unselect;
+		case SM_ACTION_TOGGLE:
+			return dp_toggle;
+	}
+	return NULL;
+}
+
 /* 1999-05-06 -	Once we have all the selection's parameters neatly tucked into <sp>, perform the
 **		actual operation.
 */
-static void do_selectre(MainInfo *min, DirPane *dp, SelParam *sp)
+static void do_selectre(MainInfo *min, DirPane *dp, SelParamRE *sp)
 {
 	GString		*tmp;
 	regex_t		re;
@@ -243,19 +280,7 @@ static void do_selectre(MainInfo *min, DirPane *dp, SelParam *sp)
 
 	if(sp->re == NULL)
 		return;
-
-	switch(sp->action)
-	{
-		case SM_ACTION_SELECT:
-			sel_action = dp_select;
-			break;
-		case SM_ACTION_UNSELECT:
-			sel_action = dp_unselect;
-			break;
-		case SM_ACTION_TOGGLE:
-			sel_action = dp_toggle;
-			break;
-	}
+	sel_action = select_action_func(sp->basic.action);
 	if((tmp = g_string_new(sp->re->str)) != NULL)
 	{
 		gint	reret;
@@ -275,10 +300,10 @@ static void do_selectre(MainInfo *min, DirPane *dp, SelParam *sp)
 
 			dp_freeze(dp);
 			matchok = sp->invert ? REG_NOMATCH : 0;
-			column  = compute_column(dp, sp->content);
+			column  = compute_column(dp, sp->basic.content);
 			for(i = 0; i < dp->dir.num_rows; i++)
 			{
-				if(filter_set(dp, i, sp) && filter_type(dp, i, sp))
+				if(filter_set(dp, i, &sp->basic) && filter_type(dp, i, &sp->basic))
 				{
 					gtk_clist_get_text(GTK_CLIST(dp->list), i, column, &text);
 					if(regexec(&re, text, 0, NULL, 0) == matchok)
@@ -344,8 +369,29 @@ static GtkWidget * build_content_menu(DirPane *dp)
 	return menu;
 }
 
+/* 2005-06-04 -	Compute which index in a content menu (as created by build_content_menu(), above)
+ * 		a given content type has. Returns 0 if <content> is not used by <dp>.
+*/
+static guint content_menu_find(const DirPane *dp, DPContent content)
+{
+	const MainInfo	*min = dp->main;
+	const DPFormat	*dpf;
+	guint		i, index;
+
+	dpf = &min->cfg.dp_format[dp->index];
+	for(i = index = 0; i < dpf->num_columns; i++)
+	{
+		if(dpf->format[i].content == DPC_ICON)
+			continue;
+		if(dpf->format[i].content == content)
+			return index;
+		index++;
+	}
+	return 0;
+}
+
 /* 1999-05-06 -	Build option menus for mode selections. */
-static void init_menus(DirPane *dp, GtkWidget *vbox, GtkWidget *opt_menu[4], guint *history[4])
+static void selparam_init_menus(DirPane *dp, GtkWidget *vbox, GtkWidget *opt_menu[4], guint *history[4])
 {
 	const gchar	*mdef[] = { N_("All rows|Selected|Unselected|"),
 				  N_("All types|Directories only|Non-directories only|"),
@@ -370,12 +416,54 @@ static void init_menus(DirPane *dp, GtkWidget *vbox, GtkWidget *opt_menu[4], gui
 	menu = build_content_menu(dp);
 	opt_menu[3] = gtk_option_menu_new();
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(opt_menu[3]), menu);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(opt_menu[3]), *history[3]);
+	gtk_option_menu_set_history(GTK_OPTION_MENU(opt_menu[3]), content_menu_find(dp, *history[3]));
 	gtk_table_attach(GTK_TABLE(table), opt_menu[3], 1, 2, i, i + 1, GTK_EXPAND|GTK_FILL,0,0,0);
 
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 }
 
+/* 2005-06-04 -	Parse out basic select parameters from command arguments. */
+static void selparam_set_from_cmdarg(SelParam *sp, const CmdArg *ca)
+{
+	const gchar	*content;
+
+	/* Always allow non-bareword arguments to alter the settings. */
+	sp->set    = car_keyword_get_enum(ca, "set", sp->set, "all rows", "selected", "unselected", NULL);
+	sp->type   = car_keyword_get_enum(ca, "type", sp->type, "all types", "directories only", "non-directories only", NULL);
+	sp->action = car_keyword_get_enum(ca, "action", sp->action, "select", "unselect", "toggle", NULL);
+	if((content = car_keyword_get_value(ca, "content", NULL)) != NULL)
+	{
+		DPContent	ac;
+
+		if((ac = dpf_get_content_from_mnemonic(content)) < DPC_NUM_TYPES)
+			sp->content = ac;
+	}
+}
+
+/* 2005-06-04 -	Get pointers to each value in a SelParam, useful with option menus and selparam_init_menus(). */
+static void selparam_get_value_pointers(guint **ptr, SelParam *sp)
+{
+	ptr[0] = &sp->set;
+	ptr[1] = &sp->type;
+	ptr[2] = &sp->action;
+	ptr[3] = (guint *) &sp->content;
+}
+
+static void selparam_read_menus(guint **ptr, GtkWidget *opt_menu[])
+{
+	GtkWidget	*menu, *mi;
+	guint		i;
+
+	for(i = 0; i < 4; i++)
+	{
+		if((menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(opt_menu[i]))) != NULL)
+		{
+			if((mi = gtk_menu_get_active(GTK_MENU(menu))) != NULL)
+				*ptr[i] = GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(mi)));
+		}
+	}
+}
+
 /* 1998-06-04 -	Pop up a dialog window asking the user for a regular expression, and
 **		then match only those entries whose names match. Very Opus.
 ** 1999-05-06 -	Basically rewritten, to accomodate command arguments in a nice way. Now
@@ -384,25 +472,14 @@ static void init_menus(DirPane *dp, GtkWidget *vbox, GtkWidget *opt_menu[4], gui
 */
 gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	SelParam	sp;
+	SelParamRE	sp;
 	const gchar	*str;
 	guint		res = 0;
-	const gchar	*content;
 
 	/* Always start from the previous set of parameters. */
-	sp = old_sp;
+	sp = old_sp_re;
 
-	/* Always allow non-bareword arguments to alter the settings. */
-	sp.set    = car_keyword_get_enum(ca, "set", sp.set, "all rows", "selected", "unselected", NULL);
-	sp.type   = car_keyword_get_enum(ca, "type", sp.type, "all types", "directories only", "non-directories only", NULL);
-	sp.action = car_keyword_get_enum(ca, "action", sp.action, "select", "unselect", "toggle", NULL);
-	if((content = car_keyword_get_value(ca, "content", "name")) != NULL)
-	{
-		DPContent	ac;
-
-		if((ac = dpf_get_content_from_mnemonic(content)) < DPC_NUM_TYPES)
-			sp.content = ac;
-	}
+	selparam_set_from_cmdarg(&sp.basic, ca);
 	sp.glob   = car_keyword_get_boolean(ca, "glob", sp.glob);
 	sp.invert = car_keyword_get_boolean(ca, "invert", sp.invert);
 	sp.full   = car_keyword_get_boolean(ca, "full", sp.full);
@@ -419,17 +496,17 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	else			/* No bareword, so pop up dialog with settings, asking for expression. */
 	{
 		GtkWidget	*vbox, *opt_menu[4], *glob, *invert, *full, *nocase, *re;
-		guint		*mptr[sizeof opt_menu / sizeof opt_menu[0]];
+		guint		*mptr[sizeof opt_menu / sizeof *opt_menu];
 		Dialog		*dlg;
 
-		mptr[0] = &sp.set;
-		mptr[1] = &sp.type;
-		mptr[2] = &sp.action;
-		mptr[3] = (guint *) &sp.content;
+		mptr[0] = &sp.basic.set;
+		mptr[1] = &sp.basic.type;
+		mptr[2] = &sp.basic.action;
+		mptr[3] = (guint *) &sp.basic.content;
 
 		vbox = gtk_vbox_new(FALSE, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 2);
-		init_menus(src, vbox, opt_menu, mptr);
+		selparam_init_menus(src, vbox, opt_menu, mptr);
 
 		glob = gtk_check_button_new_with_label(_("Treat RE as Glob Pattern?"));
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glob), sp.glob);
@@ -469,7 +546,7 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 			}
 			menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(opt_menu[3]));
 			mi   = gtk_menu_get_active(GTK_MENU(menu));
-			sp.content = (DPContent) GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(mi)));
+			sp.basic.content = (DPContent) GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(mi)));
 			sp.glob	  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glob));
 			sp.invert = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(invert));
 			sp.full   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(full));
@@ -484,7 +561,7 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	if(res == 0)
 	{
 		do_selectre(min, src, &sp);
-		old_sp = sp;		/* Make this search's parameter the defaults for the next. */
+		old_sp_re = sp;		/* Make this search's parameter the defaults for the next. */
 	}
 	return 0;
 }
@@ -529,36 +606,38 @@ gint cmd_selectsuffix(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *c
 {
 	GdkEventButton	*evt;
 	gint		row = -1;
+	const gchar	*suff = NULL;
 
-	if((evt = (GdkEventButton *) evt_event_get(GDK_BUTTON_PRESS)) != NULL)
+	if((suff = car_bareword_get(ca, 0)) != NULL)
+		;
+	if(suff == NULL)
 	{
-		gint	col;
+		if((evt = (GdkEventButton *) evt_event_get(GDK_BUTTON_PRESS)) != NULL)
+		{
+			gint	col;
 
-		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_rows))
-			row = -1;
+			if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_rows))
+				row = -1;
+		}
+		else
+			row = src->focus_row;
+		if(row != -1)
+			suff = stu_strcasechr(DP_ROW_NAME(&src->dir.row[row]), '.');
 	}
-	else
-		row = src->focus_row;
 
 	/* Did we find a row? If we did, extract its suffix, and select all matching rows. */
-	if(row != -1)
+	if(suff != NULL)
 	{
-		const gchar	*suff;
-		guint		action;
+		guint		action, i;
 		void		(*afunc)(DirPane *dp, gint row);
 
 		action = car_keyword_get_enum(ca, "action", 0, "select", "unselect", "toggle", NULL);
 		afunc = (action == 0) ? dp_select : (action == 1) ? dp_unselect : dp_toggle;
 
-		if((suff = stu_strcaserchr(DP_ROW_NAME(&src->dir.row[row]), '.')) != NULL)
+		for(i = 0; i < src->dir.num_rows; i++)
 		{
-			guint	i;
-
-			for(i = 0; i < src->dir.num_rows; i++)
-			{
-				if(stu_has_suffix(DP_ROW_NAME(&src->dir.row[i]), suff))
-					afunc(src, i);
-			}
+			if(stu_has_suffix(DP_ROW_NAME(&src->dir.row[i]), suff))
+				afunc(src, i);
 		}
 	}
 	return 1;
@@ -659,6 +738,137 @@ gint cmd_selectcmp(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	return 1;
 }
 #endif
+/* ----------------------------------------------------------------------------------------- */
+
+typedef enum { SHELL_BOOLEAN } ShellMode;
+
+typedef struct {
+	ShellMode	mode;
+} ShellRule;
+
+static int shell_select(char **argv, const char *dir, const ShellRule *rule)
+{
+	pid_t	child;
+
+	if(argv == NULL || argv[0] == NULL || rule == NULL)
+		return 0;
+
+	if((child = fork()) >= 0)
+	{
+		if(child == 0)	/* In child? */
+		{
+			fut_cd(dir, NULL, 0u);
+			execvp(argv[0], argv);
+			usleep(50000);
+			_exit(-1);
+		}
+		else if(child > 0)		/* In parent. */
+		{
+			int	stat = 0;
+
+			waitpid(child, &stat, 0);
+			if(WIFEXITED(stat))
+			{
+				stat = WEXITSTATUS(stat);
+				if(rule->mode == SHELL_BOOLEAN)
+					return stat == 0;
+				else
+					fprintf(stderr, __FILE__ ": Not handling shell select mode %d\n", rule->mode);
+			}
+			else
+				fprintf(stderr, __FILE__ ": Child command %s crashed, not interpreting return status\n", argv[0]);
+		}
+	}
+	return 0;
+}
+
+/* 2006-04-24 -	Select based on return value of shell command. */
+gint cmd_selectshell(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
+{
+	SelParamShell	sp;
+	const gchar	*str;
+	GString		*cmd;
+	guint		i, column;
+	gchar		**argv;
+	gint		reply = DLG_POSITIVE;
+
+	/* Start from previous set of parameters. */
+	sp = old_sp_shell;
+	selparam_set_from_cmdarg(&sp.basic, ca);
+	/* If bareword found, use it as command. Else, pop up the big old dialog. */
+	if((str = car_bareword_get(ca, 0)) != NULL)
+	{
+		if(sp.cmd == NULL)
+			sp.cmd = g_string_new(str);
+		else
+			g_string_assign(sp.cmd, str);
+	}
+	else
+	{
+		GtkWidget	*vbox, *opt_menu[4], *label, *entry;
+		guint		*mptr[sizeof opt_menu / sizeof *opt_menu];
+		Dialog		*dlg;
+	
+		selparam_get_value_pointers(mptr, &sp.basic);
+		vbox = gtk_vbox_new(FALSE, 0);
+		selparam_init_menus(src, vbox, opt_menu, mptr);
+		label = gtk_label_new(_("Enter shell command to run. The command\nwill have the selected content appended.\nAction is performed on successful exit."));
+		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+		entry = gtk_entry_new_with_max_length(1024);
+		if(sp.cmd != NULL)
+			gtk_entry_set_text(GTK_ENTRY(entry), sp.cmd->str);
+		gtk_box_pack_start(GTK_BOX(vbox), entry, FALSE, FALSE, 0);
+		dlg = dlg_dialog_sync_new(vbox, _("Select using shell command"), _("OK|Cancel"));
+		gtk_entry_select_region(GTK_ENTRY(entry), 0, 1 << 30);
+		gtk_widget_grab_focus(entry);
+		reply = dlg_dialog_sync_wait(dlg);
+		if(reply == DLG_POSITIVE)
+		{
+			selparam_read_menus(mptr, opt_menu);
+			if(sp.cmd == NULL)
+				sp.cmd = g_string_new(gtk_entry_get_text(GTK_ENTRY(entry)));
+			else
+				g_string_assign(sp.cmd, gtk_entry_get_text(GTK_ENTRY(entry)));
+		}
+		dlg_dialog_sync_destroy(dlg);
+	}
+
+	if(reply == DLG_POSITIVE)
+	{
+		SelAction	sel_action;
+		gchar		*text;
+
+		column = compute_column(src, sp.basic.content);
+		cmd = g_string_sized_new(4096);		/* Static for simplicity. */
+		sel_action = select_action_func(sp.basic.action);
+		for(i = 0; i < src->dir.num_rows; i++)
+		{
+			if(!filter_set(src, i, &sp.basic) || !filter_type(src, i, &sp.basic))
+				continue;
+			g_string_assign(cmd, sp.cmd->str);
+			g_string_append_c(cmd, ' ');
+			text = NULL;
+			gtk_clist_get_text(GTK_CLIST(src->list), i, column, &text);
+			if(text == NULL)
+				continue;
+			g_string_append(cmd, text);
+			if(cmd->str[0] == '\0' || cmd->str[0] == ' ')
+				continue;
+			argv = cpr_parse(min, cmd->str);
+			if(argv != NULL && argv[0] != NULL)
+			{
+				const ShellRule	rule = { SHELL_BOOLEAN };
+
+				if(shell_select(argv, src->dir.path, &rule))
+					sel_action(src, i);
+				g_free(argv);
+			}
+		}
+		g_string_free(cmd, TRUE);
+		old_sp_shell = sp;		/* Remember parameters for next time. */
+	}
+	return 0;
+}
 
 /* ----------------------------------------------------------------------------------------- */
 
