@@ -8,10 +8,10 @@
 */
 
 #include "gentoo.h"
-#include "dirpane.h"
 #include "cmdseq.h"
-#include "strutil.h"
 #include "dirhistory.h"
+#include "dirpane.h"
+#include "strutil.h"
 
 #include "cmd_swap.h"
 
@@ -59,7 +59,7 @@ gint cmd_fromother(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
 	dp_freeze(src);
 	dp_unselect_all(src);
-	csq_execute_format(min, "DirEnter 'dir=%s'", dst->dir.path);
+	csq_execute_format(min, "DirEnter 'dir=%s'", stu_escape(dst->dir.path));
 	get_selection(src, dst);
 	dp_thaw(src);
 
@@ -72,7 +72,7 @@ gint cmd_toother(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	dp_freeze(dst);
 	dp_unselect_all(dst);
 	csq_execute(min, "ActivateOther");
-	csq_execute_format(min, "DirEnter 'dir=%s'", src->dir.path);
+	csq_execute_format(min, "DirEnter 'dir=%s'", stu_escape(src->dir.path));
 	csq_execute(min, "ActivateOther");
 	get_selection(dst, src);
 	dp_thaw(dst);
