@@ -118,7 +118,7 @@ static gint file_is_text(MainInfo *min, const gchar *full_name)
 				txt = 1;
 				for(i = 0; txt && (i < got); i++)
 				{
-					if(!isprint((guchar) buf[i]) && !isspace((guchar) buf[i]))
+					if((guchar) buf[i] < 7)
 						txt = 0;
 				}
 			}
