@@ -369,10 +369,27 @@ static gint execute_builtin(MainInfo *min, const gchar *cmd)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-09-26 -	Handle a set of before or after flags. */
-void csq_handle_ba_flags(MainInfo *min, guint32 flags)
+gboolean csq_handle_ba_flags(MainInfo *min, guint32 flags)
 {
 	DirPane	*src = min->gui->cur_pane, *dst = dp_mirror(min, src);
 
+	if(flags & CBAF_REQSEL_SOURCE)
+	{
+		if(!dp_has_selection(src))
+		{
+			printf("no source sel, failing\n");
+			return FALSE;
+		}
+	}
+	if(flags & CBAF_REQSEL_DEST)
+	{
+		if(!dp_has_selection(dst))
+		{
+			printf("no dest sel, failing\n");
+			return FALSE;
+		}
+	}
+
 	if(flags & CBAF_CD_SOURCE)
 		fut_cd(src->dir.path, NULL, 0);
 	else if(flags & CBAF_CD_DEST)
@@ -382,6 +399,8 @@ void csq_handle_ba_flags(MainInfo *min, guint32 flags)
 		dp_rescan_post_cmd(src);
 	if(flags & CBAF_RESCAN_DEST)
 		dp_rescan_post_cmd(dst);
+
+	return TRUE;
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -423,7 +442,8 @@ static gint fork_and_execute(MainInfo *min, CmdRow *row, gchar **argv)
 	if(!cgr_grab_init(min, row, fd_out, fd_err))
 		return 0;
 
-	csq_handle_ba_flags(min, ext->baflags[0]);
+	if(!csq_handle_ba_flags(min, ext->baflags[0]))
+		return 0;
 
 	if((child = fork()) >= 0)
 	{
@@ -755,6 +775,7 @@ void csq_init_commands(MainInfo *min)
 	csq_add_builtin(min, "SelectSuffix",	cmd_selectsuffix,	NULL);
 /*	csq_add_builtin(min, "SelectCmp",	cmd_selectcmp,		NULL);*/
 	csq_add_builtin(min, "UnselectFirst",	cmd_unselectfirst,	NULL);
+	csq_add_builtin(min, "SelectShell",	cmd_selectshell,	NULL);
 
 	csq_add_builtin(min, "Information",	cmd_information,	cfg_information);
 
