@@ -18,11 +18,13 @@ typedef void (*DlgAsyncFunc)(gint button, gpointer user);
 
 /* ----------------------------------------------------------------------------------------- */
 
-extern void	dlg_group_set(GdkWindow *window);
+extern void	dlg_group_set(GdkWindow *group_window);
+extern void	dlg_position_set(GtkWindowPosition pos);
 
 extern Dialog *	dlg_dialog_sync_new(GtkWidget *body, const gchar *title, const gchar *buttons);
 extern Dialog *	dlg_dialog_sync_new_simple(const gchar *body, const gchar *title, const gchar *buttons);
 extern gint	dlg_dialog_sync_new_simple_wait(const gchar *body, const gchar *title, const gchar *buttons);
+extern void	dlg_dialog_sync_stay_open(Dialog *dlg);
 extern gint	dlg_dialog_sync_wait(Dialog *dlg);
 extern void	dlg_dialog_sync_close(Dialog *dlg, gint button);
 extern void	dlg_dialog_sync_destroy(Dialog *dlg);
