@@ -16,10 +16,12 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "strutil.h"
-#include "fileutil.h"
-#include "userinfo.h"
+#include "errors.h"
 #include "progress.h"
+#include "strutil.h"
+#include "userinfo.h"
+
+#include "fileutil.h"
 
 /* ----------------------------------------------------------------------------------------- */
 
@@ -59,7 +61,6 @@ GList * fut_stat_chain_new(const gchar *path)
 		return NULL;
 
 	dir = g_string_new(canon);
-	printf("chaining '%s'\n", canon);
 
 	while(dir->len && strcmp(dir->str, G_DIR_SEPARATOR_S) != 0)
 	{
@@ -72,7 +73,6 @@ GList * fut_stat_chain_new(const gchar *path)
 
 			*st = stbuf;
 			chain = g_list_append(chain, st);
-			printf("chain: got <%llu,%llu> for '%s'\n", st->st_dev, st->st_ino, dir->str);
 			if((sep = strrchr(dir->str, G_DIR_SEPARATOR)) != NULL)
 				g_string_truncate(dir, sep - dir->str);
 			else
@@ -96,12 +96,10 @@ gboolean fut_stat_chain_prefix_equal(const GList *chain1, const GList *chain2)
 	if(!chain1 || !chain2)
 		return FALSE;
 
-	printf("prefix: chain1=%p chain2=%p\n", chain1, chain2);
 	for(; chain1 && chain2; chain1 = g_list_next(chain1), chain2 = g_list_next(chain2))
 	{
 		const struct stat	*s1 = chain1->data, *s2 = chain2->data;
 
-		printf("comparing stats at %p,%p\n", s1, s2);
 		if(s1->st_dev != s2->st_dev || s1->st_ino != s2->st_ino)
 			return FALSE;
 	}
@@ -190,6 +188,24 @@ gboolean fut_path_canonicalize(const gchar *path, gchar *outpath, gsize maxout)
 	return FALSE;
 }
 
+/* 2003-10-10 -	Check if the directory <to> is a child directory of <from>. If it is, copying <from>
+**		into <to> is a genuine Bad Idea.
+*/
+gboolean fut_is_parent_of(const char *from, const char *to)
+{
+	gchar	buf1[PATH_MAX], buf2[PATH_MAX];
+
+	if(fut_path_canonicalize(from, buf1, sizeof buf1) &&
+	   fut_path_canonicalize(to,   buf2, sizeof buf2))
+	{
+		gsize	len = strlen(buf1);
+
+		if(strncmp(buf1, buf2, len) == 0)
+			return buf2[len] == G_DIR_SEPARATOR;	/* If last char is /, buf1 is really a prefix. */
+	}
+	return FALSE;
+}
+
 /* 1998-09-23 -	Return 1 if the named file exists, 0 otherwise. Since this is Unix
 **		(I think), this matter is somewhat complex. But I choose to ignore
 **		that for now, and pretend it's nice and simple. :)
@@ -250,6 +266,7 @@ static gint recurse_dir_size(MainInfo *min, const gchar *path, guint64 *bytes, F
 	{
 		if((dir = opendir(".")) != NULL)
 		{
+			err_clear(min);
 			while((de = readdir(dir)) != NULL)
 			{
 				if(with_progress)
