@@ -178,6 +178,7 @@ static GtkWidget * build_top(GtkWidget **label)
 	top = gtk_event_box_new();
 	hbox = gtk_hbox_new(FALSE, 0);
 	lab = od_label_new("");
+	gtk_widget_set_name(lab, "mainStatus");
 	GTK_WIDGET_SET_FLAGS(GTK_WIDGET(lab), GTK_CAN_FOCUS);
 	gtk_box_pack_start(GTK_BOX(hbox), lab, TRUE, TRUE, 0);
 	gtk_container_add(GTK_CONTAINER(top), hbox);
@@ -457,8 +458,12 @@ static gint evt_idle_run(gpointer user)
 
 int main(int argc, char *argv[])
 {
-	enum { OPT_VERSION = 1 << 0, OPT_ROOTOK = 1 << 1, OPT_NORC = 1 << 2, OPT_NOGTKRC = 1 << 3, OPT_NOFAM = 1 << 4 };
+	enum { OPT_VERSION = 1 << 0, OPT_LOCALEINFO = 1 << 1, OPT_ROOTOK = 1 << 2,
+		OPT_NORC = 1 << 3, OPT_NOGTKRC = 1 << 4, OPT_NOFAM = 1 << 5 };
 	OptDesc	od[] = { { '\0', "version",  OPT_ARG_NONE, OPT_VERSION,	N_("Report the version to standard output, and exit.") },
+#if defined ENABLE_NLS
+			 { '\0', "locale-info", OPT_ARG_NONE, OPT_LOCALEINFO, N_("Reports internal locale details, and exits.") },
+#endif
 			 { '\0', "root-ok",  OPT_ARG_NONE, OPT_ROOTOK,	N_("Allows gentoo to be run by the root user. Could be dangerous.") },
 			 { '\0', "no-rc",    OPT_ARG_NONE, OPT_NORC,	N_("Do not load the ~/.gentoorc configuration file; instead, use default values.") },
 			 { '\0', "no-gtkrc", OPT_ARG_NONE, OPT_NOGTKRC,	N_("Do not load the ~/.gentoogtkrc GTK+ configuration file; instead, use system defaults.") },
@@ -478,9 +483,13 @@ int main(int argc, char *argv[])
 	min.opt     = od;
 	min.opt_num = sizeof od / sizeof *od;
 	
-#if defined ENABLE_NLS	
+#if defined ENABLE_NLS
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
+	if(bindtextdomain(PACKAGE, LOCALEDIR) == NULL)
+	{
+		fprintf(stderr, _("%s: Couldn't set text domain to \"%s\"\n"), argv[0], LOCALEDIR);
+		return EXIT_FAILURE;
+	}
 	textdomain(PACKAGE);
 	for(opt_flags = 0; opt_flags < sizeof od / sizeof *od; opt_flags++)
 		od[opt_flags].help = _(od[opt_flags].help);
@@ -494,6 +503,14 @@ int main(int argc, char *argv[])
 		puts(VERSION);
 		return EXIT_SUCCESS;
 	}
+#if defined ENABLE_NLS
+	if(opt_flags & OPT_LOCALEINFO)
+	{
+		printf("PACKAGE=\"%s\"\n", PACKAGE);
+		printf("LOCALEDIR=\"%s\"\n", LOCALEDIR);
+		return EXIT_SUCCESS;
+	}
+#endif
 	if(geteuid() == 0 && !(opt_flags & OPT_ROOTOK))
 	{
 		fprintf(stderr, _("%s: To run as root, envoke with the '--root-ok' option\n"), argv[0]);
