@@ -16,6 +16,7 @@
 
 #include "fileutil.h"
 #include "dirpane.h"
+#include "miscutil.h"
 #include "sizeutil.h"
 #include "progress.h"
 
@@ -289,6 +290,7 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 
 			micro = 1E6 * (time_now.tv_sec  - pgs_info.time_begin.tv_sec) + 
 				      (time_now.tv_usec - pgs_info.time_begin.tv_usec);
+
 			if(micro >= pgs_info.delay_time)
 				pgs_info.delayed = FALSE;
 		}
@@ -296,8 +298,7 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 		{
 			if(pgs_info.eta != NULL)
 			{
-				gfloat	secs = (time_now.tv_sec - pgs_info.time_begin.tv_sec) + 
-						1E-6 * (time_now.tv_usec - pgs_info.time_begin.tv_usec);
+				gfloat	secs = msu_diff_timeval(&pgs_info.time_begin, &time_now);
 				if((guint) secs != pgs_info.last_secs)
 				{
 					gchar	buf[64], spdbuf[16];
