@@ -2,6 +2,9 @@
 ** 1998-09-30 -	Header file for the progress reporting module. Pretty simple.
 */
 
+#if !defined PROGRESS_H
+#define	PROGRESS_H
+
 typedef enum { PGS_CANCEL, PGS_PROCEED } PgsRes;
 
 #define	PFLG_COUNT_RECURSIVE	(1<<0)	/* Count # of items recursively? */
@@ -14,12 +17,14 @@ typedef enum { PGS_CANCEL, PGS_PROCEED } PgsRes;
 /* Call this to set up an operation, which is assumed to consist of doing
 ** something to a bunch of items.
 */
-void	pgs_progress_begin(MainInfo *min, const gchar *op_name, guint32 flags);
+extern void	pgs_progress_begin(MainInfo *min, const gchar *op_name, guint32 flags);
 
 /* Use these three calls to report the progress of each item. */
-void	pgs_progress_item_begin(MainInfo *min, const gchar *name, gsize size);
-PgsRes	pgs_progress_item_update(MainInfo *min, gsize pos);
-void	pgs_progress_item_end(MainInfo *min);
+extern void	pgs_progress_item_begin(MainInfo *min, const gchar *name, off_t size);
+extern PgsRes	pgs_progress_item_update(MainInfo *min, off_t pos);
+extern void	pgs_progress_item_end(MainInfo *min);
 
 /* Call this when the operation as a whole is completed. */
-void	pgs_progress_end(MainInfo *min);
+extern void	pgs_progress_end(MainInfo *min);
+
+#endif		/* PROGRESS_H */
