@@ -133,24 +133,24 @@ guint sze_put_size(gchar *buf, gsize buf_max, off_t size, SzUnit unit)
 	switch(unit)
 	{
 		case SZE_NONE:
-			return g_snprintf(buf, buf_max, "%u", size);
+			return g_snprintf(buf, buf_max, "%Lu", (guint64) size);
 		case SZE_BYTES:
-			return g_snprintf(buf, buf_max, _("%u bytes"), size);
+			return g_snprintf(buf, buf_max, _("%Lu bytes"), (guint64) size);
 		case SZE_KB:
 			if((size & ((1 << 10) - 1)) == 0)
-				return g_snprintf(buf, buf_max, _("%u KB"), size >> 10);
+				return g_snprintf(buf, buf_max, _("%Lu KB"), (guint64) size >> 10);
 			temp = (double) size / (1 << 10);
 			fmt  = _("%.2f KB");
 			break;
 		case SZE_MB:
 			if((size & ((1 << 20) - 1)) == 0)
-				return g_snprintf(buf, buf_max, _("%u MB"), size >> 20);
+				return g_snprintf(buf, buf_max, _("%Lu MB"), (guint64) size >> 20);
 			temp = (double) size / (1 << 20);
 			fmt  = _("%.2f MB");
 			break;
 		case SZE_GB:
 			if((size & ((1 << 30) - 1)) == 0)
-				return g_snprintf(buf, buf_max, _("%u GB"), size >> 30);
+				return g_snprintf(buf, buf_max, _("%Lu GB"), (guint64) size >> 30);
 			temp = (double) size / (1 << 30);
 			fmt  = _("%.2f GB");
 			break;
