@@ -398,3 +398,25 @@ gchar ** stu_split_args(const gchar *argstring)
 
 	return argv;
 }
+
+/* ----------------------------------------------------------------------------------------- */
+
+/* 2003-11-25 -	Create internal (static, be careful!) version of <string> where certain
+**		characters have been escaped by backslashes, and return pointer to it.
+*/
+const gchar * stu_escape(const gchar *string)
+{
+	static GString	*str = NULL;
+
+	if(str == NULL)
+		str = g_string_new("");
+	else
+		g_string_truncate(str, 0);
+	for(; *string; string++)
+	{
+		if(*string == '"' || *string == '\'' || *string == '\\')
+			g_string_append_c(str, '\\');
+		g_string_append_c(str, *string);
+	}
+	return str->str;
+}
