@@ -72,7 +72,7 @@ WinInfo * win_wininfo_new_default(MainInfo *min)
 	win_window_size_use_set(wi, WIN_CONFIG, TRUE);
 	win_window_size_update_set(wi, WIN_CONFIG, TRUE);
 
-	win_window_new(wi, WIN_TEXTVIEW,	WIN_TYPE_SIMPLE_DIALOG,	  FALSE, _("Text Viewer"), "textview");
+	win_window_new(wi, WIN_TEXTVIEW,	WIN_TYPE_SIMPLE_TOPLEVEL, FALSE, _("Text Viewer"), "textview");
 	win_window_pos_use_set(wi, WIN_TEXTVIEW, TRUE);
 	win_window_size_set(wi, WIN_TEXTVIEW, 640, 480);
 	win_window_size_use_set(wi, WIN_TEXTVIEW, TRUE);
