@@ -1437,7 +1437,7 @@ void od_emil_button_set_text (ODEmilButton *button, guint index, const gchar *te
 		  #if DEBUG
 			puts("od_emil_button_set_text(): setting label text on old label widget");
 		  #endif
-			gtk_label_set_text(GTK_LABEL(widget), text);
+			gtk_label_parse_uline(GTK_LABEL(widget), text);
 			if (GTK_WIDGET(button)->parent)
 				gtk_widget_queue_resize (GTK_WIDGET(button));
 			if (GTK_WIDGET_DRAWABLE(button))
@@ -1451,14 +1451,16 @@ void od_emil_button_set_text (ODEmilButton *button, guint index, const gchar *te
 			style = gtk_widget_get_style(widget);
 			od_emil_button_remove_widget(button, index);
 			
-			widget = gtk_label_new(text);
+			widget = gtk_label_new("");
+			gtk_label_parse_uline(GTK_LABEL(widget), text);
 			gtk_widget_set_style(widget, style);
 		}
 	} else {
 	  #if DEBUG
 		puts("od_emil_button_set_text(): creating new label");
 	  #endif
-		widget = gtk_label_new(text);
+		widget = gtk_label_new("");
+		gtk_label_parse_uline(GTK_LABEL(widget), text);
 	}
 	gtk_misc_set_alignment (GTK_MISC (widget), 0.5, 0.5);
 	od_emil_button_set_widget(button, index, widget, button->choices[index].user_data);
